@@ -2,7 +2,7 @@
 l_ld <- function(beta, x, n, Start, Stop, Event){
   fit.cox <- coxph(Surv(Start, Stop, Event) ~ x,
                    init = beta,
-                   control = list('iter.max' = 0, timefix = FALSE))
+                   control = coxph.control(iter.max = 0, timefix = FALSE))
   l <- - fit.cox$loglik[1]/n
   ld <- - fit.cox$first/n
   return(c(l, ld))
